//! # Admin logs management
//!
//! @author Pierre Hubert

use crate::constants::conservation_policy::ADMIN_ACTIONS_LOG_LIFETIME;
use crate::constants::database_tables_names::ADMIN_LOGS_TABLE;
use crate::data::admin::AdminID;
use crate::data::admin_action_log::AdminAction;
use crate::data::error::Res;
use crate::helpers::database;
use crate::utils::date_utils::time;

/// Record an administrator action
pub fn log_admin_action(admin: AdminID, ip: &str, action: AdminAction) -> Res {
    database::InsertQuery::new(ADMIN_LOGS_TABLE)
        .add_admin_id("admin_id", admin)
        .add_str("ip", ip)
        .add_u64("time", time())
        .add_str("action", &serde_json::to_string(&action)?)
        .insert_drop_result()
}

/// Clean old admin logs
pub fn clean_old_logs() -> Res {
    database::DeleteQuery::new(ADMIN_LOGS_TABLE)
        .set_custom_where("time < ?")
        .add_custom_where_arg_u64(time() - ADMIN_ACTIONS_LOG_LIFETIME.as_secs())
        .exec()
}